;------------------------------------------------------------------------------
; File Name :      main.asm
;------------------------------------------------------------------------------
;      Copyright: Eugene M. Hutorny  2006
;      Revision:  V1.01
;      Date:      Aug 25, 2006
;      License:   Licensed to public under the Open Software License 
;                 http://www.opensource.org/licenses/osl-3.0.php
;------------------------------------------------------------------------------
; VELOOS Example1, device PIC16F690
;------------------------------------------------------------------------------
; This example implements a simple application that toggles port on a
; message received. Measuring generated frequency we can estimate system 
; throughput. With Fosc = 8 MHz (INTOSC) system can handle at most 
; 13 messages per mSec (overhead is ~150 IC per message)
; Any activity added to the application will lower this throughput.

 include "pic.inc"
 include "vos.inc"

;------------------------------------------------------------------------------
 __CONFIG _WDT_ON & _INTRC_OSC_NOCLKOUT & _CP_OFF & _PWRTE_ON & _MCLRE_ON & _FCMEN_OFF & _BOR_OFF & _IESO_OFF
;------------------------------------------------------------------------------

 constant mask = .2                         ; mask to be used for driving port (RA1)
 constant msgid = 040h                      ; message ID

VOS_Classes                                 ; Class definitions begin
MyClass VOS_mClass MyHandler, MyInit        ; MyClass implementes MyHandler and MyInit methods
                                            ; Class definitions end with beginning of the next code section
VOS_Objects                                 ; Object registry begins
MyObject    
  VOS_mPersistentObject MyClass, mask       ; Instance of MyClass constructed with object data == mask
                                            ; Object registry ends with beginning of the code next section
;------------------------------------------------------------------------------
    code
MyInit                                      ; This was loaded with object data
    comf        This, W                     ; W := ~mask
    banksel     TRISA
    movwf       TRISA                       ; Prepare port for output
    VOS_mPostMessage MyObject, msgid        ; post message to itself
    return
;------------------------------------------------------------------------------

MyHandler                                   ; FSR points to message ID field, This is loaded with object data
    movlw       msgid
    xorwf       INDF, W                     ; if message.msg_id <> msgid
    skpz
    return                                  ; return
    movf        This, W
    banksel     PORTA
    xorwf       PORTA, F                    ; Toggle port
    VOS_mPostMessage MyObject, msgid        ; post message to itself
    return
;------------------------------------------------------------------------------

VOS_BootHandlers code                       ; starts a section for the application boot handler
    banksel     ANSEL
    clrf        ANSEL                       ; Turn all pints to digital
    clrf        ANSELH
    banksel     OSCCON                      ; Set Fosc = 8Mhz
    movlw       (.7 << IRCF0)
    movwf       OSCCON
    ; !!! NO RETURN ALLOWED !!!
;------------------------------------------------------------------------------
    
 end
