;------------------------------------------------------------------------------
; File Name :      pic.inc
;------------------------------------------------------------------------------
;      Copyright: Eugene M. Hutorny  2003-2006
;      Revision:  V1.01
;      Date:      Aug 25, 2006
;      License:   Licensed to public under the Open Software License 
;                 http://www.opensource.org/licenses/osl-3.0.php
;------------------------------------------------------------------------------
;
;------------------------------------------------------------------------------
; Processor specific, board/schema/application independed, primitives.
;------------------------------------------------------------------------------
           SUBTITLE        "Processor specific definitions"
;------------------------------------------------------------------------------
#define __pic_inc
; Generic commonly used constants
 constant false = 0
 constant true  = ~false
 variable _osc_clock = 0

; Processor family constants
 constant _pic10 = .10
 constant _pic12 = .12
 constant _pic16 = .16
 constant _pic18 = .18
; processor constants
 constant _pic10F202  = 10F202Fh
 constant _pic12F629  = 12F629Fh
 constant _pic12F675  = 12F675Fh
 constant _pic16F84A  = 16F84AFh
 constant _pic16F628  = 16F628Fh
 constant _pic16F628A = 16F628Ah
 constant _pic16F648A = 16F648Ah
 constant _pic16F677  = 16F677Fh
 constant _pic16F685  = 16F685Fh
 constant _pic16F687  = 16F687Fh
 constant _pic16F689  = 16F689Fh
 constant _pic16F690  = 16F690Fh
 constant _pic16F88   = 16F88FFh
 constant _pic18F248  = 18F248Fh
 constant _pic18F258  = 18F258Fh
 constant _pic18F448  = 18F448Fh
 constant _pic18F458  = 18F458Fh
 ;
 variable _pic_fam    = 0     ; unknown family (yet)
 variable _pic        = 0     ; unknown device (yet)
 variable _pic_maxram = 0
 variable _pic_maxrom = 0
 variable _pic_maxeeprom = 0
; PIC10F202
        ifdef __10F202
			include         "p10f202.inc"
            include         "pic16.inc"
_pic                        = _pic10F202
_pic_maxram                 = 001Fh
_pic_maxrom                 = 01FFh
_pic_maxeeprom              = 000h
_osc_clock                  = .4000000    	; internal OSC frequency
_pic_shrram                 = 00h			; number of bytes in a shared bank, should be 0 
											; if no banking or when all memory is shared
        endif
; PIC12F675
        ifdef __12F675
			include         "p12f675.inc"
            include         "pic16.inc"
_pic_fam                    = _pic12
_pic                        = _pic12F675
_pic_maxram                 = 005Fh
_pic_maxrom                 = 03FFh
_pic_maxeeprom              = 07Fh
_osc_clock                  = .4000000    ; internal OSC frequency
_pic_shrram                 = 00h
        endif
; PIC16F690
        ifdef __16F690
			include         "p16f690.inc"
            include         "pic16.inc"
_pic                        = _pic16F690
_pic_maxram                 = 016Fh       ; with shared bank excluded
_pic_maxrom                 = 0FFFh
_pic_maxeeprom              = 0FFh
_osc_clock                  = .8000000    ; internal OSC frequency
        endif
; PIC16F88
        ifdef __16F88
			include         "p16f88.inc"
            include         "pic16.inc"            
_pic                        = _pic16F88
_pic_maxram                 = 01FFh
_pic_maxrom                 = 0FFFh
_pic_maxeeprom              = 0FFh
        endif
; PIC18F248
        ifdef __18F248
			include         "p18f248.inc"
            include         "pic18.inc"
_pic                        = _pic18F248
_pic_maxram                 = 02FFh
_pic_maxrom                 = 3FFFh
_pic_maxeeprom              = 0FFh
_osc_clock                  = .8000000    ; internal OSC frequency
        endif

;------------------------------------------------------------------------------
; ASSEMBLER SPECIFIC DEFINITIONS
;------------------------------------------------------------------------------
interface macro
#ifdef public
#undefine public
#endif
#define public extern
 endm

implementation macro
#ifdef public
#undefine public
#endif
#define public global
 endm

;------------------------------------------------------------------------------
; Verification of PIC model
 if _pic_maxram == 0
   error "_pic_maxram is not properly set, please check device section"
 endif

 if _pic_maxrom == 0
   error "_pic_maxrom is not properly set, please check device section"
 endif

 if _pic == 0
   error "_pic constant (device ID) is not properly set, please check device section"
 endif

 if _pic_fam == 0
   error "_pic constant (device ID) is not properly set, please check device section"
 endif

 if _osc_clock == 0
   error "_osc_clock is not properly set, please check device section"
 endif
